;;; -*- mode: Lisp; Syntax: Common-Lisp; -*-
;;;
;;; Copyright (c) 2008 by the authors.
;;;
;;; See LICENCE for details.

(cl:in-package :cl-user)

;;; try to load asdf-system-connections
(eval-when (:compile-toplevel :load-toplevel :execute)
  (flet ((try (system)
           (unless (asdf:find-system system nil)
             (warn "Trying to install required dependency: ~S" system)
             (when (find-package :asdf-install)
               (funcall (read-from-string "asdf-install:install") system))
             (unless (asdf:find-system system nil)
               (error "The ~A system requires ~A." (or *compile-file-pathname* *load-pathname*) system)))
           (asdf:operate 'asdf:load-op system)))
    (try :asdf-system-connections)))

(defpackage #:cl-syntax-sugar-system
  (:use :cl :asdf))

(in-package #:cl-syntax-sugar-system)

(defsystem :slim-cl-syntax-sugar
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "A slim version of syntax sugar without any syntax's defined"
  :depends-on (:alexandria :metabang-bind)
  :components
  ((:module "src"
            :components ((:file "package")
                         (:file "duplicates" :depends-on ("package"))
                         (:file "asdf-integration" :depends-on ("package" "duplicates"))
                         (:file "syntax-sugar" :depends-on ("duplicates")))
	    )))

(defsystem-connection slim-cl-syntax-sugar-and-swank
  :requires (:slim-cl-syntax-sugar :swank)
  :components
  ((:module "src"
            :components ((:file "swank-integration")))))

(defsystem :lambda-with-bang-args-syntax
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "the lambda syntax that is packaged by default with cl-syntax-sugar"
  :depends-on (:slim-cl-syntax-sugar :cl-walker)
  :components
  ((:module "src"
            :components ((:file "cl-walker-integration")
			 (:file "lambda" :depends-on ("cl-walker-integration")))
	    )))

(defsystem :quasi-quote-syntax
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "the quasi-quote-syntax that is packaged by default with cl-syntax-sugar"
  :depends-on (:slim-cl-syntax-sugar)
  :components
  ((:module "src"
	    :components ((:file "one-liners")
			 (:file "quasi-quote" :depends-on ("one-liners"))))))

(defsystem :readtime-wrapper-syntax
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "the readtime-wrapper-syntax that is packaged by default with cl-syntax-sugar"
  :depends-on (:slim-cl-syntax-sugar)
  :components
  ((:module "src"
            :components ((:file "one-liners")
			 (:file "readtime-wrapper" :depends-on ("one-liners")))
	    )))

(defsystem :string-quote-syntax
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "the string-quote-syntax that is packaged by default with cl-syntax-sugar"
  :depends-on (:slim-cl-syntax-sugar)
  :components
  ((:module "src"
            :components ((:file "one-liners")
			 (:file "string-quote" :depends-on ("one-liners"))))))

(defsystem :feature-cond-syntax
  :author ("Levente Mészáros <levente.meszaros@gmail.com>"
           "Attila Lendvai <attila.lendvai@gmail.com>")
  :licence "BSD / Public Domain"
  :description "the feature-cond-syntax that is packaged by default with cl-syntax-sugar"
  :depends-on (:slim-cl-syntax-sugar)
  :components
  ((:module "src"
            :components ((:file "one-liners")
			 (:file "feature-cond" :depends-on ("one-liners"))))))
